@@ -104,12 +104,12 @@ config_class_init (GtkObjectClass *object_class)
 	e_table_config_signals [CHANGED] =
 		gtk_signal_new ("changed",
 				GTK_RUN_LAST,
-				object_class->type,
+				E_OBJECT_CLASS_TYPE (object_class),
 				GTK_SIGNAL_OFFSET (ETableConfigClass, changed),
 				gtk_marshal_NONE__NONE,
 				GTK_TYPE_NONE, 0);
 
-	gtk_object_class_add_signals (object_class, e_table_config_signals, LAST_SIGNAL);
+	E_OBJECT_CLASS_ADD_SIGNALS (object_class, e_table_config_signals, LAST_SIGNAL);
 
 	gtk_object_add_arg_type ("ETableConfig::state", E_TABLE_STATE_TYPE,
 				 GTK_ARG_READABLE, ARG_STATE);
@@ -465,9 +465,10 @@ connect_button (ETableConfig *config, GladeXML *gui, const char *widget_name, vo
 {
 	GtkWidget *button = glade_xml_get_widget (gui, widget_name);
 
-	gtk_signal_connect(
-		GTK_OBJECT (button), "clicked",
-		GTK_SIGNAL_FUNC (cback), config);
+	if (button) {
+		gtk_signal_connect (GTK_OBJECT (button), "clicked",
+				    GTK_SIGNAL_FUNC (cback), config);
+	}
 }
 
 static void
@@ -687,8 +688,13 @@ configure_group_dialog (ETableConfig *config, GladeXML *gui)
 static void
 setup_gui (ETableConfig *config)
 {
-	GladeXML *gui = glade_xml_new_with_domain (
-		ETABLE_GLADEDIR "/e-table-config.glade", NULL, PACKAGE);
+	GladeXML *gui;
+
+	if (e_table_sort_info_get_can_group (config->state->sort_info)) {
+		gui = glade_xml_new_with_domain (ETABLE_GLADEDIR "/e-table-config.glade", NULL, PACKAGE);
+	} else {
+		gui = glade_xml_new_with_domain (ETABLE_GLADEDIR "/e-table-config-no-group.glade", NULL, PACKAGE);
+	}
 	
 	config->dialog_toplevel = glade_xml_get_widget (
 		gui, "e-table-config");
@@ -726,7 +732,7 @@ setup_gui (ETableConfig *config)
 	gtk_signal_connect (
 		GTK_OBJECT (config->dialog_toplevel), "apply",
 		GTK_SIGNAL_FUNC (dialog_apply), config);
-	
+
 	gtk_object_unref (GTK_OBJECT (gui));
 }
 
