@@ -10,6 +10,7 @@
 
 #include <config.h>
 #include "gal/util/e-i18n.h"
+#include "gal/util/e-util.h"
 #include "e-table-utils.h"
 #include "e-table-header-utils.h"
 
@@ -74,14 +75,14 @@ et_col_spec_to_col (ETableColumnSpecification *col_spec,
 					col_spec->model_col, gettext (col_spec->title),
 					pixbuf, col_spec->expansion,
 					col_spec->minimum_width,
-					cell, compare, col_spec->resizable);
+					cell, compare, col_spec->resizable, col_spec->priority);
 			}
 		}
 		if (col == NULL && col_spec->title && *col_spec->title) {
 			col = e_table_col_new (
 				col_spec->model_col, gettext (col_spec->title),
 				col_spec->expansion, col_spec->minimum_width,
-				cell, compare, col_spec->resizable);
+				cell, compare, col_spec->resizable, col_spec->priority);
 		}
 	}
 	return col;
