@@ -9,12 +9,12 @@
 
 BEGIN_GNOME_DECLS
 
-ETableHeader *
-e_table_state_to_header (GtkWidget *widget, ETableHeader *full_header, ETableState *state);
+ETableHeader *e_table_state_to_header            (GtkWidget           *widget,
+						  ETableHeader        *full_header,
+						  ETableState         *state);
 
-ETableHeader *
-e_table_spec_to_full_header (ETableSpecification *spec,
-			     ETableExtras        *ete);
+ETableHeader *e_table_spec_to_full_header        (ETableSpecification *spec,
+						  ETableExtras        *ete);
 
 END_GNOME_DECLS
 
