@@ -46,7 +46,7 @@ ecmlc_ecml_changed (ECategoriesMasterList *ecml, ECategoriesMasterListCombo *ecm
 			e_categories_master_list_nth (ecml, i));
 		strings = g_list_prepend (strings, category);
 	}
-	strings = g_list_reverse (strings);
+	strings = g_list_sort (strings, (GCompareFunc) g_utf8_collate);
 	strings = g_list_prepend (strings, g_strdup (""));
 	gtk_combo_set_popdown_strings (GTK_COMBO (ecmlc), strings);
 	g_list_foreach (strings, (GFunc) g_free, NULL);
